| /freebsd-13.1/contrib/llvm-project/compiler-rt/lib/tsan/rtl/ |
| H A D | tsan_dispatch_defs.h | 60 # define SANITIZER_WEAK_IMPORT extern "C" __attribute((weak_import)) 62 # define SANITIZER_WEAK_IMPORT extern "C" __attribute((weak))
|
| /freebsd-13.1/contrib/libpcap/pcap/ |
| H A D | funcattrs.h | 173 #define PCAP_NORETURN __attribute((noreturn)) 174 #define PCAP_NORETURN_DEF __attribute((noreturn))
|
| /freebsd-13.1/contrib/llvm-project/clang/lib/Headers/ |
| H A D | __clang_cuda_runtime_wrapper.h | 350 __device__ void free(void *) __attribute((nothrow)); 351 __device__ void *malloc(size_t) __attribute((nothrow)) __attribute__((malloc));
|
| /freebsd-13.1/contrib/tcpdump/ |
| H A D | funcattrs.h | 78 #define NORETURN __attribute((noreturn))
|
| H A D | configure | 3660 main(int argc __attribute((unused)), char **argv __attribute((unused)))
|
| /freebsd-13.1/crypto/openssl/crypto/modes/ |
| H A D | ofb128.c | 15 typedef size_t size_t_aX __attribute((__aligned__(1))); typedef
|
| H A D | ctr128.c | 15 typedef size_t size_t_aX __attribute((__aligned__(1))); typedef
|
| H A D | cbc128.c | 19 typedef size_t size_t_aX __attribute((__aligned__(1))); typedef
|
| H A D | xts128.c | 16 typedef u64 u64_a1 __attribute((__aligned__(1))); typedef
|
| H A D | cfb128.c | 15 typedef size_t size_t_aX __attribute((__aligned__(1))); typedef
|
| H A D | modes_local.h | 42 typedef u32 u32_a1 __attribute((__aligned__(1))); typedef
|
| H A D | ccm128.c | 16 typedef u64 u64_a1 __attribute((__aligned__(1))); typedef
|
| H A D | gcm128.c | 15 typedef size_t size_t_aX __attribute((__aligned__(1))); typedef
|
| /freebsd-13.1/contrib/llvm-project/compiler-rt/lib/hwasan/ |
| H A D | hwasan_dynamic_shadow.cpp | 86 extern __attribute((weak, visibility("hidden"))) ElfW(Rela) __rela_iplt_start[],
|
| /freebsd-13.1/contrib/llvm-project/compiler-rt/lib/profile/ |
| H A D | InstrProfilingPort.h | 39 #define COMPILER_RT_ALWAYS_INLINE inline __attribute((always_inline))
|
| /freebsd-13.1/sbin/routed/rtquery/ |
| H A D | rtquery.c | 129 static void trace_loop(char *argv[]) __attribute((__noreturn__)); 130 static void query_loop(char *argv[], int) __attribute((__noreturn__));
|
| /freebsd-13.1/crypto/openssl/crypto/aes/ |
| H A D | aes_ige.c | 26 } aes_block_t __attribute((__aligned__(1))); typedef
|
| /freebsd-13.1/crypto/openssl/crypto/whrlpool/ |
| H A D | wp_block.c | 68 typedef u64 u64_a1 __attribute((__aligned__(1))); typedef 75 typedef u64 u64_aX __attribute((__aligned__(1))); typedef
|
| /freebsd-13.1/sys/contrib/octeon-sdk/ |
| H A D | cvmx-debug.c | 115 static char cvmx_debug_stack[8*1024] __attribute ((aligned (16))); 133 static char cvmx_debug_stack_all[CVMX_MAX_CORES][8*1024] __attribute ((aligned (16)));
|
| /freebsd-13.1/contrib/llvm-project/llvm/include/llvm/ADT/ |
| H A D | StringRef.h | 902 __attribute((enable_if(__builtin_strlen(Str) == N - 1, in StringLiteral()
|
| /freebsd-13.1/contrib/llvm-project/clang/include/clang/Basic/ |
| H A D | TokenKinds.def | 427 KEYWORD(__attribute , KEYALL) 632 ALIAS("__attribute__", __attribute, KEYALL)
|
| /freebsd-13.1/crypto/openssl/crypto/ec/ |
| H A D | ecp_nistp224.c | 75 typedef uint64_t limb_aX __attribute((__aligned__(1)));
|
| H A D | ecp_nistz256.c | 35 # define ALIGN32 __attribute((aligned(32)))
|
| H A D | ecp_nistp521.c | 131 typedef limb limb_aX __attribute((__aligned__(1)));
|
| H A D | ecp_nistz256_table.c | 25 __attribute((aligned(4096)))
|